@@ -23,6 +23,8 @@
 void
 Init_gtk4(void)
 {
+    rb_gtk4_cell_layout_init();
+    rb_gtk4_tree_view_init();
     rb_gtk4_widget_init();
     rb_gtk4_window_init();
 }
